rhythmmakertools.DurationSpellingSpecifier
==========================================

.. abjad-lineage:: abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier

.. autoclass:: abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.decrease_durations_monotonically
      ~abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.forbidden_written_duration
      ~abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.reverse
      ~abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.__eq__
      ~abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.__format__
      ~abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.__hash__
      ~abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.__ne__
      ~abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.__repr__

Bases
-----

- :py:class:`abctools.AbjadValueObject <abjad.tools.abctools.AbjadValueObject.AbjadValueObject>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.decrease_durations_monotonically
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.forbidden_written_duration
   :noindex:

Methods
-------

.. automethod:: abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.reverse
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.__eq__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.__format__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.__hash__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.__ne__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.DurationSpellingSpecifier.DurationSpellingSpecifier.__repr__
   :noindex:
